@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v2.3.1';
+our $VERSION = 'v2.3.2';
 
 use Narada::Config qw( get_config_line );
 use Log::Fast;
@@ -64,8 +64,7 @@ Narada::Log - setup project log
 
 =head1 VERSION
 
-This document describes Narada::Log version v2.3.1
-    use Narada::Log qw( $LOG );
+This document describes Narada::Log version v2.3.2    use Narada::Log qw( $LOG );
 
     $LOG->INFO("ready to work");
 
